@@ -1,7 +1,7 @@
 package App::dateseq;
 
-our $DATE = '2019-05-24'; # DATE
-our $VERSION = '0.091'; # VERSION
+our $DATE = '2019-05-26'; # DATE
+our $VERSION = '0.092'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,6 @@ _
                 'x.perl.coerce_to' => 'DateTime',
                 'x.perl.coerce_rules' => ['str_alami_en'],
             }],
-            req => 1,
             pos => 0,
         },
         to => {
@@ -85,6 +84,13 @@ _
         },
     },
     examples => [
+        {
+            summary => 'Generate "infinite" dates from today',
+            src => '[[prog]]',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             summary => 'Generate dates from 2015-01-01 to 2015-01-31',
             src => '[[prog]] 2015-01-01 2015-01-31',
@@ -93,7 +99,7 @@ _
         },
         {
             summary => 'Generate dates from yesterday to 2 weeks from now',
-            src => '[[prog]] yesterday "in 2 weeks"',
+            src => '[[prog]] yesterday "2 weeks from now"',
             src_plang => 'bash',
             'x.doc.max_result_lines' => 5,
         },
@@ -103,13 +109,6 @@ _
             src_plang => 'bash',
             'x.doc.max_result_lines' => 5,
         },
-        {
-            summary => 'Generate "infinite" dates from 2015-01-01',
-            src => '[[prog]] 2015-01-01',
-            src_plang => 'bash',
-            test => 0,
-            'x.doc.show_result' => 0,
-        },
         {
             summary => 'Generate "infinite" dates from 2015-01-01 (reverse)',
             src => '[[prog]] 2015-01-01 -r',
@@ -130,13 +129,13 @@ _
             'x.doc.max_result_lines' => 5,
         },
         {
-            summary => 'Generate first 20 business days after 2015-01-01',
+            summary => 'Generate first 20 business days (Mon-Fri) after 2015-01-01',
             src => '[[prog]] 2015-01-01 --business -n 20 -f "%Y-%m-%d(%a)"',
             src_plang => 'bash',
             'x.doc.max_result_lines' => 10,
         },
         {
-            summary => 'Generate first 5 non-business days (Sat/Sun) after 2015-01-01',
+            summary => 'Generate first 5 non-business days (Sat-Sun) after 2015-01-01',
             src => '[[prog]] 2015-01-01 --no-business -n 5',
             src_plang => 'bash',
             'x.doc.max_result_lines' => 5,
@@ -179,6 +178,7 @@ sub dateseq {
 
     my %args = @_;
 
+    $args{from} //= DateTime->today;
     $args{increment} //= DateTime::Duration->new(days=>1);
     my $reverse = $args{reverse};
 
@@ -279,7 +279,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.091 of App::dateseq (from Perl distribution App-dateseq), released on 2019-05-24.
+This document describes version 0.092 of App::dateseq (from Perl distribution App-dateseq), released on 2019-05-26.
 
 =head1 FUNCTIONS
 
@@ -316,7 +316,7 @@ strftime() format for each date.
 Default is C<%Y-%m-%d>, unless when hour/minute/second is specified, then it is
 C<%Y-%m-%dT%H:%M:%S>.
 
-=item * B<from>* => I<date>
+=item * B<from> => I<date>
 
 Starting date.
 
